@@ -1,14 +1,31 @@
+# type: ignore
+
 """
 Contains all of the SqlAlchemy models for the Fides resources.
 """
 
 from typing import Dict
 
-from sqlalchemy import ARRAY, JSON, Column, Integer, String, Text
+from sqlalchemy import (
+    ARRAY,
+    JSON,
+    Column,
+    Integer,
+    String,
+    Text,
+    type_coerce,
+    TypeDecorator,
+    cast,
+)
+from sqlalchemy.dialects.postgresql import BYTEA
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.sql import func
 from sqlalchemy.sql.sqltypes import DateTime
 
+from fidesctl.core.config import FidesctlConfig, get_config
+
+CONFIG: FidesctlConfig = get_config()
+
 
 class SqlModelBase:
     """
@@ -38,6 +55,45 @@ class FidesBase(SqlModelBase):
 SqlAlchemyBase = declarative_base(cls=SqlModelBase)
 
 
+class PGEncryptedString(TypeDecorator):
+    """
+    This TypeDecorator handles encrypting and decrypting values at rest
+    on the database that would normally be stored as json.
+
+    The values are explicitly cast as json then text to take advantage of
+    the pgcrypto extension.
+    """
+
+    impl = BYTEA
+    python_type = String
+
+    cache_ok = True
+
+    def __init__(self):
+        super().__init__()
+
+        self.passphrase = CONFIG.user.encryption_key
+
+    def bind_expression(self, bindparam):
+        # Needs to be a string for the encryption, however it also needs to be treated as JSON first
+
+        bindparam = type_coerce(bindparam, JSON)
+
+        return func.pgp_sym_encrypt(cast(bindparam, Text), self.passphrase)
+
+    def column_expression(self, column):
+        return cast(func.pgp_sym_decrypt(column, self.passphrase), JSON)
+
+    def process_bind_param(self, value, dialect):
+        pass
+
+    def process_literal_param(self, value, dialect):
+        pass
+
+    def process_result_value(self, value, dialect):
+        pass
+
+
 # Privacy Types
 class DataCategory(SqlAlchemyBase, FidesBase):
     """
@@ -89,6 +145,7 @@ class Dataset(SqlAlchemyBase, FidesBase):
     data_categories = Column(ARRAY(String))
     data_qualifier = Column(String)
     collections = Column(JSON)
+    joint_controller = Column(PGEncryptedString, nullable=True)
 
 
 # Evaluation
@@ -115,6 +172,9 @@ class Organization(SqlAlchemyBase, FidesBase):
     __tablename__ = "organizations"
 
     organization_parent_key = Column(String, nullable=True)
+    controller = Column(PGEncryptedString, nullable=True)
+    data_protection_officer = Column(PGEncryptedString, nullable=True)
+    representative = Column(PGEncryptedString, nullable=True)
 
 
 # Policy
@@ -149,6 +209,7 @@ class System(SqlAlchemyBase, FidesBase):
     meta = Column(JSON)
     system_type = Column(String)
     system_dependencies = Column(ARRAY(String))
+    joint_controller = Column(PGEncryptedString, nullable=True)
     privacy_declarations = Column(JSON)
 
 
