@@ -2,23 +2,19 @@
 import click
 
 import fidesctl
-from fidesctl.cli.cli import (
+from fidesctl.core.config import get_config
+
+from .core_commands import (
+    annotate_dataset,
     apply,
-    delete,
     evaluate,
+    export,
     generate_dataset,
     scan,
-    annotate_dataset,
-    get,
-    init_db,
-    ls,
     parse,
-    ping,
-    reset_db,
-    view_config,
-    webserver,
 )
-from fidesctl.core.config import get_config
+from .crud_commands import delete, get, ls
+from .util_comands import init, init_db, reset_db, ping, webserver, view_config
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 LOCAL_COMMANDS = [evaluate, parse, view_config]
@@ -26,9 +22,11 @@ API_COMMANDS = [
     annotate_dataset,
     apply,
     delete,
+    export,
     generate_dataset,
     scan,
     get,
+    init,
     init_db,
     ls,
     ping,
@@ -40,7 +38,6 @@ API_COMMANDS = [
 @click.group(
     context_settings=CONTEXT_SETTINGS,
     invoke_without_command=True,
-    chain=True,
     name="fidesctl",
 )
 @click.version_option(version=fidesctl.__version__)
