@@ -6,11 +6,9 @@ from typing import Union, List
 
 import click
 
-## TODO: decouple this from fidesapi, it should be using API calls
-from fidesapi.crud import list_resource
-from fidesapi.sql_models import sql_model_map
-from fidesctl.core import parse as core_parse
-from fidesctl.core import visualize
+from fidesctl.core import parse as core_parse, api_helpers
+from fidesctl.core.config import FidesctlConfig
+from fidesctl.core.utils import get_all_level_fields
 from fideslang import manifests
 from fideslang.models import Dataset, DatasetCollection, DatasetField, FidesKey
 from fideslang.validation import FidesValidationError
@@ -85,6 +83,7 @@ def get_data_categories_annotation(
 
 
 def annotate_dataset(
+    config: FidesctlConfig,
     dataset_file: str,
     resource_type: str = "data_category",
     annotate_all: bool = False,
@@ -103,57 +102,56 @@ def annotate_dataset(
         Write the amended dataset file in place
     """
     output_dataset = []
+    url = config.cli.server_url
+    headers = config.user.request_headers
 
     # Make the user aware of the data_categories visualizer
     click.secho(
-        f"""For reference, open the data category visualizer at either (localhost if running container):
-        {visualize.get_visualize_url(resource_type, "graphs")}
-        {visualize.get_visualize_url(resource_type, "text")}
-    """,
+        "For reference, you can use the Taxonomy explorer at the '/<resource_type>/visualize/graphs/' endpoint on a running fidesctl webserver.",
         fg="green",
     )
 
     datasets = core_parse.ingest_manifests(dataset_file)["dataset"]
 
     existing_categories = [
-        resource.__dict__["fides_key"]
-        for resource in list_resource(sql_model_map[resource_type])
+        resource.fides_key
+        for resource in api_helpers.list_server_resources(
+            url=url, resource_type=resource_type, headers=headers
+        )
     ]
 
     for dataset in datasets:
         current_dataset = Dataset(**dataset)
-        click.secho(f"\n####\nAnnotating Dataset: [{current_dataset.name}]")
+        try:
+            click.secho(f"\n####\nAnnotating Dataset: [{current_dataset.name}]")
 
-        if annotate_all and not current_dataset.data_categories:
-            try:
+            # Check for data_categories at the Dataset level
+            if annotate_all and not current_dataset.data_categories:
                 click.secho(f"Database [{current_dataset.name}] has no data categories")
                 current_dataset.data_categories = get_data_categories_annotation(
                     dataset_member=current_dataset,
                     valid_categories=existing_categories,
                     validate=validate,
                 )
-            except AnnotationAbortError:
-                break
 
-        for table in current_dataset.collections:
-            click.secho(f"####\nAnnotating Table: [{table.name}]\n")
-            if annotate_all and not table.data_categories:
-                try:
+            # Check for data_categories at the collections level
+            for table in current_dataset.collections:
+                click.secho(f"####\nAnnotating Table: [{table.name}]\n")
+                if annotate_all and not table.data_categories:
                     click.secho(f"Table [{table.name}] has no data categories")
                     table.data_categories = get_data_categories_annotation(
                         dataset_member=table,
                         valid_categories=existing_categories,
                         validate=validate,
                     )
-                except AnnotationAbortError:
-                    break
 
-            for field in table.fields:
-                if not field.data_categories:
-                    click.secho(
-                        f"Field [{table.name}.{field.name}] has no data categories\n"
-                    )
-                    try:
+                # Check for data_categories at the field level
+                for field in get_all_level_fields(table.fields):
+                    if not field.data_categories:
+                        click.secho(
+                            f"Field [{table.name}.{field.name}] has no data categories\n",
+                            fg="red",
+                        )
                         user_categories = get_data_categories_annotation(
                             dataset_member=field,
                             valid_categories=existing_categories,
@@ -161,11 +159,12 @@ def annotate_dataset(
                         )
                         click.secho(
                             f"""Setting data categories for {table.name}.{field.name} to:
-                        {user_categories}\n"""
+                        {user_categories}\n""",
+                            fg="green",
                         )
                         field.data_categories = user_categories
-                    except AnnotationAbortError:
-                        break
-    else:
-        output_dataset.append(current_dataset.dict())
+            output_dataset.append(current_dataset.dict())
+        except AnnotationAbortError:
+            output_dataset.append(current_dataset.dict())
+            break
     manifests.write_manifest(dataset_file, output_dataset, "dataset")
