@@ -14,16 +14,16 @@ class FidesValidationError(Exception):
 
 class FidesKey(ConstrainedStr):
     """
-    A FidesKey should only contain alphanumeric characters, '.' or '_'
+    A FidesKey type that creates a custom constrained string.
     """
 
-    regex: Pattern[str] = re.compile(r"^[a-zA-Z0-9_.]+$")
+    regex: Pattern[str] = re.compile(r"^[a-zA-Z0-9_.-]+$")
 
     @classmethod  # This overrides the default method to throw the custom FidesValidationError
     def validate(cls, value: str) -> str:
         if not cls.regex.match(value):
             raise FidesValidationError(
-                "FidesKey must only contain alphanumeric characters, '.' or '_'."
+                "FidesKey must only contain alphanumeric characters, '.', '_' or '-'."
             )
 
         return value
